import React, { useRef } from 'react';
import purebem from 'purebem';
import useAutoFocus from '@billogram/use-auto-focus';
import useRadioButtonGroup from '@billogram/use-radio-button-group';
import './FoundationRadioButtonGroup.scss';

function noop() {}

export default function FoundationRadioButtonGroup(_ref) {
  var _ref$autoFocus = _ref.autoFocus,
      autoFocus = _ref$autoFocus === void 0 ? false : _ref$autoFocus,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value;
  var block = purebem('foundation-radio-button-group');
  var radioButtonGroupRef = useRef(null);
  useAutoFocus(radioButtonGroupRef, autoFocus);

  var _useRadioButtonGroup = useRadioButtonGroup({
    disabled: disabled,
    onChange: onChange,
    options: options,
    value: value
  }),
      change = _useRadioButtonGroup.change,
      handleKeyDown = _useRadioButtonGroup.handleKeyDown,
      selectedOption = _useRadioButtonGroup.selectedOption; // We intend to follow these resources as closely as possible (not quite there yet though):
  //  - https://www.w3.org/TR/wai-aria-practices/#radiobutton
  //  - https://www.w3.org/TR/wai-aria-practices/examples/radio/radio-1/radio-1.html


  return React.createElement("div", {
    className: block({
      disabled: disabled
    }),
    onKeyDown: handleKeyDown,
    ref: radioButtonGroupRef,
    role: "radiogroup",
    tabIndex: disabled || options.every(function (option) {
      return option.disabled;
    }) ? void 0 : 0
  }, options.map(function (option) {
    var checked = selectedOption !== null && selectedOption.value === option.value;
    var unchecked = !checked;
    var optionDisabled = disabled || option.disabled;

    function handleChange() {
      change(option);
    }

    return React.createElement("div", {
      "aria-checked": checked,
      className: block('item', {
        checked: checked,
        disabled: optionDisabled,
        unchecked: unchecked
      }),
      key: option.value,
      onClick: handleChange,
      role: "radio"
    }, React.createElement("span", {
      className: block('item-icon', {
        checked: checked,
        disabled: optionDisabled,
        unchecked: unchecked
      })
    }), React.createElement("span", {
      className: block('item-content', {
        disabled: optionDisabled
      })
    }, option.text));
  }));
}
//# sourceMappingURL=FoundationRadioButtonGroup.js.map